/* Copyright (c) 1994 by Oracle Corporation.  All Rights Reserved.
 *
 * mzn.h - OMN Name Server Public Interface
 *
 * DESCRIPTION
 * Related man pages are mznBind(3) and mznInsEntry(3).
 *
 * REVISIONS
 * jolkin     08/08/94  Moved comments to man pages
 * jolkin     06/08/94  Creation
 */

#ifndef MZN_ORACLE
#define MZN_ORACLE

#ifndef SX_ORACLE
#include <sx.h>
#endif
#ifndef MN_ORACLE
#include <mn.h>
#endif
#ifndef MNR_ORACLE
#include <mnr.h>
#endif
#ifndef MNX_ORACLE
#include <mnx.h>
#endif

EXTC_START

/* name server types */
typedef struct mznent mznent;

/* name server RPC identifiers */
#define MZNMADDR  "0xffffffff.2"

#ifndef lint
extern const mnrid mznPid;
extern const mnrid mznCid;
#else
externref CONST_DATA mnrid mznPid;
externref CONST_DATA mnrid mznCid;
#endif /* lint */

/* query types for mznQuery() */
#define MZN_PORTS        0x0001
#define MZN_PROGRAMS     0x0002
#define MZN_ALL_PROGRAMS 0x0006
#define MZN_ALL_NAMES    0x0007

/* name server entry descriptor */
/* DISABLE check_naming */
struct mznent
{
  const char  *name;                                        /* name of entry */
  const mnrid *id;                                     /* program identifier */
  mna          addr;                                    /* address for entry */
  mnbv        *attr;                                       /* attribute list */
  ub4          nattr;                                /* number of attributes */
};
/* ENABLE check_naming */

/* named ports */
sb4 mznBind(mnp *, const char *);
sb4 mznFind(mna *, const char *);
sb4 mznUnbind(mnp *);

/* name server entries */
sb4 mznInsEntry(mznent *);
sb4 mznFndEntry(const char *, const mnrid *, mznent *);
sb4 mznDelEntry(const char *, const mnrid *);
sb4 mznQuery(const char *, ub4, mnxStream *);
sb4 mznMakeAlias(const char *, const char *);

/* name server client side cache */
void mznInvalidateCache(void);

/* entry marshalling routine */
boolean mznxEntry(mnx *, dvoid *);

EXTC_END
#endif /* MZN_ORACLE */
