/* Copyright (c) 1995 by Oracle Corporation.  All Rights Reserved.
 *
 * ysid.h - Media Net System Identifiers
 *
 * DESCRIPTION
 * System identifiers are used to uniquely identify a number of constant
 * entities used throughout Media Net, including exceptions and interface
 * types.  These are equivalent to repository IDs in CORBA and as such,
 * are defined publicly as strings.
 */

#ifndef YSID_ORACLE
#define YSID_ORACLE

#ifndef SYSX_ORACLE
#include <sysx.h>
#endif

EXTC_START

/*
 * ysid - declarations
 */
#define ysid char
#define ysidDecl(nm)      CONST_DATA char nm[]

externref ysidDecl(YS_PRODUCT);

/*
 * ysidEq, ysidToStr - identifier manipulation
 *
 * DESCRIPTION
 * ysidEq() is used to compare two identifiers for equality.  ysidToStr()
 * is used to convert a system identifier to a printable text string.
 */
#define ysidEq(id1, id2)  (!strcmp((id1), (id2)))
#define ysidToStr(id)     (id)

/*
 * Global Exceptions
 */
externref ysidDecl(YS_EX_FAILURE);
externref ysidDecl(YS_EX_NOTINIT);
externref ysidDecl(YS_EX_NOTIMPL);
externref ysidDecl(YS_EX_BADPARAM);
externref ysidDecl(YS_EX_BADMAGIC);
externref ysidDecl(YS_EX_ALREADY);
externref ysidDecl(YS_EX_INUSE);
externref ysidDecl(YS_EX_SHUTDOWN);

EXTC_END
#endif /* YSID_ORACLE */
